@@ -32,6 +32,11 @@ logger = logging.getLogger(__name__)
 MAX_FILENAME_LENGTH = 95
 
 
+async def adjust(s: str, length: int = 40, placeholder: str = "...") -> str:
+    """Collapse and truncate or pad the given string to fit in the given length"""
+    return f"{s[:length - len(placeholder)]}{placeholder}" if len(s) >= length else s.ljust(length)
+
+
 async def clear() -> None:
     """Clears the terminal screen"""
     os.system('cls' if os.name == 'nt' else 'clear')
@@ -59,22 +64,6 @@ async def purge_dir(dirname) -> None:
     list(map(os.rmdir, deleted))
 
 
-async def get_db_path(url: URL, referer=None):
-    """Gets the URL path to be put into the DB and checked from the DB"""
-    url_path = url.path
-    if 'anonfiles' in url.host or 'bayfiles' in url.host:
-        url_path = url_path.split('/')
-        url_path.pop(0)
-        if len(url_path) > 1:
-            url_path.pop(1)
-        url_path = '/' + '/'.join(url_path)
-
-    if referer and "e-hentai" in referer:
-        url_path = url_path.split('keystamp')[0][:-1]
-
-    return url_path
-
-
 async def sanitize(name: str) -> str:
     """Simple sanitization to remove illegal characters"""
     return re.sub(r'[<>:"/\\|?*\']', "", name).strip()
@@ -82,6 +71,9 @@ async def sanitize(name: str) -> str:
 
 async def make_title_safe(title: str) -> str:
     """Simple sanitization to remove illegal characters from titles and trim the length to be less than 60 chars"""
+    title = title.replace("\n", "").strip()
+    title = title.replace("\t", "").strip()
+    title = re.sub(' +', ' ', title)
     title = re.sub(r'[\\*?:"<>|./]', "-", title)
     title = title[:60].strip()
     return title
@@ -104,5 +96,6 @@ async def get_filename_and_ext(filename, forum=False):
         filename_parts = filename_parts[0].rsplit('-', 1)
     ext = "." + filename_parts[-1].lower()
     filename = filename_parts[0][:MAX_FILENAME_LENGTH] if len(filename_parts[0]) > MAX_FILENAME_LENGTH else filename_parts[0]
+    filename = filename.strip()
     filename = await sanitize(filename + ext)
     return filename, ext
