@@ -1,6 +1,6 @@
 from yarl import URL
 
-from ..base_functions.base_functions import log, logger, make_title_safe, get_filename_and_ext, get_db_path
+from ..base_functions.base_functions import get_filename_and_ext, log, logger, make_title_safe
 from ..base_functions.data_classes import AlbumItem, MediaItem
 from ..base_functions.sql_helper import SQLHelper
 from ..client.client import ScrapeSession
@@ -18,8 +18,7 @@ class HGameCGCrawler:
         await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
         await self.get_album(session, url, album_obj)
         await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
-        url_path = await get_db_path(url)
-        await self.SQL_Helper.insert_album("hgamecg", url_path, album_obj)
+        await self.SQL_Helper.insert_album("hgamecg", url, album_obj)
         return album_obj
 
     async def get_album(self, session: ScrapeSession, url: URL, album_obj: AlbumItem):
@@ -35,8 +34,7 @@ class HGameCGCrawler:
                 image = URL("https://" + url.host + image)
                 link = await self.get_image(session, image)
 
-                url_path = await get_db_path(link)
-                complete = await self.SQL_Helper.check_complete_singular("hgamecg", url_path)
+                complete = await self.SQL_Helper.check_complete_singular("hgamecg", link)
 
                 filename, ext = await get_filename_and_ext(link.name)
                 media_item = MediaItem(link, image, complete, filename, ext, filename)
