@@ -1,7 +1,8 @@
+import itertools
+
 from yarl import URL
 
-from ..base_functions.base_functions import log, logger, make_title_safe, get_filename_and_ext, \
-    get_db_path
+from ..base_functions.base_functions import get_filename_and_ext, log, logger, make_title_safe
 from ..base_functions.data_classes import MediaItem, DomainItem
 from ..base_functions.error_classes import NoExtensionFailure
 from ..base_functions.sql_helper import SQLHelper
@@ -23,17 +24,15 @@ class NSFWXXXCrawler:
             await self.get_user(session, url, domain_obj)
         else:
             await self.get_post(session, url, domain_obj)
-        url_path = await get_db_path(url)
-        await self.SQL_Helper.insert_domain("nsfw.xxx", url_path, domain_obj)
+        await self.SQL_Helper.insert_domain("nsfw.xxx", url, domain_obj)
         return domain_obj
 
     async def get_user(self, session: ScrapeSession, url: URL, domain_obj: DomainItem):
         """Gets posts for a user profile"""
         try:
-            page = 1
             model = url.name + " (NSFW.XXX)"
-            while True:
-                page_url = URL(f"https://nsfw.xxx/page/{str(page)}?nsfw[]=0&types[]=image&types[]=video&types[]=gallery&slider=1&jsload=1&user={url.name}")
+            for page in itertools.count(1):
+                page_url = URL(f"https://nsfw.xxx/page/{page}?nsfw[]=0&types[]=image&types[]=video&types[]=gallery&slider=1&jsload=1&user={url.name}")
                 page_soup = await session.get_BS4(page_url)
 
                 posts = page_soup.select('div[class="sh-section__image grid-item"] a[class=slider_init_href]')
@@ -46,7 +45,6 @@ class NSFWXXXCrawler:
                 posts = await self.get_post_hrefs(posts)
                 for post in posts:
                     await self.get_post(session, post, domain_obj, model)
-                page += 1
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
@@ -78,8 +76,7 @@ class NSFWXXXCrawler:
                 link = URL(content.get("src"))
                 if "-mobile" in link.name or ".webm" in link.name:
                     continue
-                url_path = await get_db_path(link)
-                complete = await self.SQL_Helper.check_complete_singular("nsfw.xxx", url_path)
+                complete = await self.SQL_Helper.check_complete_singular("nsfw.xxx", link)
                 try:
                     filename, ext = await get_filename_and_ext(link.name)
                 except NoExtensionFailure:
