@@ -1,9 +1,8 @@
 from __future__ import annotations
 
 import asyncio
+import itertools
 import logging
-import multiprocessing
-from functools import wraps
 from http import HTTPStatus
 from random import gauss
 
@@ -11,17 +10,16 @@ import aiofiles
 import aiohttp.client_exceptions
 from rich.live import Live
 from rich.progress import TaskID
-from yarl import URL
 
 from cyberdrop_dl.base_functions.base_functions import (
+    adjust,
     clear,
-    get_db_path,
     log,
     logger,
 )
 from cyberdrop_dl.base_functions.data_classes import AlbumItem, CascadeItem, DomainItem, FileLock, ForumItem, MediaItem
 from cyberdrop_dl.base_functions.error_classes import DownloadFailure
-from cyberdrop_dl.base_functions.sql_helper import SQLHelper
+from cyberdrop_dl.base_functions.sql_helper import SQLHelper, get_db_path
 from cyberdrop_dl.client.client import Client, DownloadSession
 from cyberdrop_dl.scraper.Scraper import ScrapeMapper
 
@@ -30,7 +28,9 @@ from .downloader_utils import (
     allowed_filetype,
     basic_auth,
     check_free_space,
+    get_threads_number,
     is_4xx_client_error,
+    retry,
 )
 from .progress_definitions import (
     album_progress,
@@ -44,28 +44,6 @@ from .progress_definitions import (
 )
 
 
-def retry(f):
-    """This function is a wrapper that handles retrying for failed downloads"""
-
-    @wraps(f)
-    async def wrapper(self, *args, **kwargs):
-        while True:
-            try:
-                return await f(self, *args, **kwargs)
-            except DownloadFailure as e:
-                if not self.disable_attempt_limit and self.current_attempt[args[3]] >= self.allowed_attempts - 1:
-                    await self.output_failed(args[2], e)
-                    logger.debug('Skipping %s...', args[2].url, exc_info=True)
-                    overall_file_progress.advance(self.files.failed_files_task_id, 1)
-                    self.files.failed_files += 1
-                    return
-                logger.debug(e.message)
-                logger.debug(f'Retrying ({self.current_attempt[args[3]]}) {args[2].url}...')
-                self.current_attempt[args[3]] += 1
-
-    return wrapper
-
-
 class Files:
     """Class that keeps track of completed, skipped and failed files"""
 
@@ -87,7 +65,7 @@ class Downloader:
     """Downloader class, directs downloading for domain objects"""
 
     def __init__(self, args: dict, client: Client, SQL_Helper: SQLHelper, scraper: ScrapeMapper, max_workers: int,
-                 domain: str, domain_obj: DomainItem, semaphore: asyncio.Semaphore, files: Files):
+                 domain: str, domain_obj: DomainItem, files: Files):
         self.backup_scraper = scraper
         self.client = client
         self.download_session = DownloadSession(client)
@@ -104,7 +82,7 @@ class Downloader:
 
         self.current_attempt = {}
         self.max_workers = max_workers
-        self._semaphore = semaphore
+        self._semaphore = asyncio.Semaphore(max_workers)
         self.delay = {'cyberfile': 1, 'anonfiles': 1, "coomer": 0.2, "kemono": 0.2}
 
         self.pixeldrain_api_key = args["Authentication"]["pixeldrain_api_key"]
@@ -139,10 +117,7 @@ class Downloader:
             return
         task_description = album.split('/')[-1]
         task_description = task_description.encode("ascii", "ignore").decode().strip()
-        if len(task_description) >= 40:
-            task_description = task_description[:37] + "..."
-        else:
-            task_description = task_description.ljust(40)
+        task_description = await adjust(task_description)
         album_task = album_progress.add_task("[pink3]" + task_description.upper(), total=len(album_obj.media))
         download_tasks = []
         for media in album_obj.media:
@@ -153,27 +128,18 @@ class Downloader:
 
     async def start_file(self, album_task: TaskID, album: str, media: MediaItem):
         """Handler for files and the progress bars for it"""
-        if media.complete:
+        if media.complete or await self.SQL_Helper.check_complete_singular(self.domain, media.url):
             await log(f"Previously Downloaded: {media.filename}", quiet=True)
             overall_file_progress.advance(self.files.skipped_files_task_id, 1)
             self.files.skipped_files += 1
             album_progress.advance(album_task, 1)
             return
-        else:
-            url_path = await get_db_path(URL(media.url), self.domain)
-            complete = await self.SQL_Helper.check_complete_singular(self.domain, url_path)
-            if complete:
-                await log(f"Previously Downloaded: {media.filename}", quiet=True)
-                overall_file_progress.advance(self.files.skipped_files_task_id, 1)
-                self.files.skipped_files += 1
-                album_progress.advance(album_task, 1)
-                return
         async with self._semaphore:
-            url_path = await get_db_path(URL(media.url), self.domain)
-            await self.download_file(album_task, album, media, url_path)
+            url_path = await get_db_path(media.url, self.domain)
+            await self.download_file(album, media, url_path, album_task)
 
     @retry
-    async def download_file(self, album_task: TaskID, album: str, media: MediaItem, url_path: str):
+    async def download_file(self, album: str, media: MediaItem, url_path: str, album_task: TaskID) -> None:
         """File downloader"""
         if not await check_free_space(self.required_free_space, self.download_dir):
             await log("We've run out of free space.", quiet=True)
@@ -237,12 +203,8 @@ class Downloader:
             if range_num:
                 headers['Range'] = range_num
 
-            task_description = media.filename
-            task_description = task_description.encode("ascii", "ignore").decode().strip()
-            if len(task_description) >= 40:
-                task_description = task_description[:37] + "..."
-            else:
-                task_description = task_description.ljust(40)
+            task_description = media.filename.encode("ascii", "ignore").decode().strip()
+            task_description = await adjust(task_description)
             file_task = file_progress.add_task("[plum3]" + task_description, progress_type="file")
 
             if not await self.SQL_Helper.sql_check_old_existing(url_path) and not fake_download:
@@ -318,6 +280,9 @@ class Downloader:
             async with aiofiles.open(self.errored_file, mode='a') as file:
                 await file.write(f"{media.url},{media.referer},{e.message}\n")
 
+    async def failed_files_progress(self) -> None:
+        overall_file_progress.advance(self.files.failed_files_task_id, 1)
+
     async def check_file_exists(self, complete_file, partial_file, media, album, url_path, original_filename,
                                 current_throttle):
         """Complicated checker for if a file already exists, and was already downloaded"""
@@ -358,10 +323,8 @@ class Downloader:
         return complete_file, partial_file, proceed
 
     async def iterate_filename(self, complete_file, media, album):
-        iterations = 1
-        while True:
+        for iterations in itertools.count(1):
             filename = f"{complete_file.stem} ({iterations}){media.ext}"
-            iterations += 1
             temp_complete_file = (self.download_dir / album / filename)
             if not temp_complete_file.exists() and not await self.SQL_Helper.check_filename(filename):
                 media.filename = filename
@@ -374,8 +337,6 @@ class Downloader:
 async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelper, client: Client,
                            scraper: ScrapeMapper) -> None:
     """Handler for cascades and the progress bars for it"""
-    user_threads = args["Runtime"]["simultaneous_downloads_per_domain"]
-
     progress_table = await get_cascade_table(args["Progress_Options"])
     total_files = await Cascade.get_total()
     files = Files(overall_file_progress.add_task("[green]Completed", total=total_files),
@@ -385,17 +346,11 @@ async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelp
         cascade_task = cascade_progress.add_task("[light_salmon3]Domains", progress_type="cascade",
                                                  total=len(Cascade.domains))
 
-        downloaders = []
         tasks = []
 
         for domain, domain_obj in Cascade.domains.items():
-            threads = user_threads if user_threads != 0 else multiprocessing.cpu_count()
-            if 'bunkr' in domain or 'pixeldrain' in domain or 'anonfiles' in domain:
-                threads = 2 if (threads > 2) else threads
-            download_semaphore = asyncio.Semaphore(threads)
-            downloaders.append(Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
-                                          download_semaphore, files))
-        for downloader in downloaders:
+            threads = await get_threads_number(args, domain)
+            downloader = Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj, files)
             tasks.append(downloader.start_domain(cascade_task))
         await asyncio.gather(*tasks)
 
@@ -411,8 +366,6 @@ async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelp
 async def download_forums(args: dict, Forums: ForumItem, SQL_Helper: SQLHelper, client: Client,
                           scraper: ScrapeMapper) -> None:
     """Handler for forum threads and the progress bars for it"""
-    user_threads = args["Runtime"]["simultaneous_downloads_per_domain"]
-
     progress_table = await get_forum_table(args["Progress_Options"])
     total_files = await Forums.get_total()
     files = Files(overall_file_progress.add_task("[green]Completed", total=total_files),
@@ -423,17 +376,11 @@ async def download_forums(args: dict, Forums: ForumItem, SQL_Helper: SQLHelper,
         for title, Cascade in Forums.threads.items():
             cascade_task = cascade_progress.add_task("[light_salmon3]" + title.upper(), total=len(Cascade.domains))
 
-            downloaders = []
             tasks = []
 
             for domain, domain_obj in Cascade.domains.items():
-                threads = user_threads if user_threads != 0 else multiprocessing.cpu_count()
-                if 'bunkr' in domain or 'pixeldrain' in domain or 'anonfiles' in domain:
-                    threads = 2 if (threads > 2) else threads
-                download_semaphore = asyncio.Semaphore(threads)
-                downloaders.append(Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
-                                              download_semaphore, files))
-            for downloader in downloaders:
+                threads = await get_threads_number(args, domain)
+                downloader = Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj, files)
                 tasks.append(downloader.start_domain(cascade_task))
             await asyncio.gather(*tasks)
             cascade_progress.update(cascade_task, visible=False)
