@@ -1,26 +1,23 @@
 from __future__ import annotations
 
 import asyncio
+import itertools
 import logging
-import multiprocessing
-from functools import wraps
 from http import HTTPStatus
 from random import gauss
 
 import aiofiles
 import aiohttp.client_exceptions
 from tqdm import tqdm
-from yarl import URL
 
 from cyberdrop_dl.base_functions.base_functions import (
     clear,
-    get_db_path,
     log,
     logger,
 )
 from cyberdrop_dl.base_functions.data_classes import AlbumItem, CascadeItem, DomainItem, FileLock, ForumItem, MediaItem
 from cyberdrop_dl.base_functions.error_classes import DownloadFailure
-from cyberdrop_dl.base_functions.sql_helper import SQLHelper
+from cyberdrop_dl.base_functions.sql_helper import SQLHelper, get_db_path
 from cyberdrop_dl.client.client import Client, DownloadSession
 from cyberdrop_dl.scraper.Scraper import ScrapeMapper
 
@@ -29,32 +26,12 @@ from .downloader_utils import (
     allowed_filetype,
     basic_auth,
     check_free_space,
+    get_threads_number,
     is_4xx_client_error,
+    retry,
 )
 
 
-def retry(f):
-    """This function is a wrapper that handles retrying for failed downloads"""
-
-    @wraps(f)
-    async def wrapper(self, *args, **kwargs):
-        while True:
-            try:
-                return await f(self, *args, **kwargs)
-            except DownloadFailure as e:
-                if not self.disable_attempt_limit and self.current_attempt[args[2]] >= self.allowed_attempts - 1:
-                    await self.output_failed(args[1], e)
-                    logger.debug('Skipping %s...', args[1].url, exc_info=True)
-                    self.files.failed_files += 1
-                    self.progress.update(1)
-                    return
-                logger.debug(e.message)
-                logger.debug(f'Retrying ({self.current_attempt[args[2]]}) {args[1].url}...')
-                self.current_attempt[args[2]] += 1
-
-    return wrapper
-
-
 class Files:
     """Class that keeps track of completed, skipped and failed files"""
 
@@ -68,7 +45,7 @@ class Old_Downloader:
     """Downloader class, directs downloading for domain objects"""
 
     def __init__(self, args: dict, client: Client, SQL_Helper: SQLHelper, scraper: ScrapeMapper, max_workers: int,
-                 domain: str, domain_obj: DomainItem, semaphore: asyncio.Semaphore, files: Files, progress: tqdm):
+                 domain: str, domain_obj: DomainItem, files: Files, progress: tqdm):
         self.backup_scraper = scraper
         self.client = client
         self.download_session = DownloadSession(client)
@@ -86,7 +63,7 @@ class Old_Downloader:
 
         self.current_attempt = {}
         self.max_workers = max_workers
-        self._semaphore = semaphore
+        self._semaphore = asyncio.Semaphore(max_workers)
         self.delay = {'cyberfile': 1, 'anonfiles': 1, "coomer": 0.2, "kemono": 0.2}
 
         self.pixeldrain_api_key = args["Authentication"]["pixeldrain_api_key"]
@@ -123,25 +100,17 @@ class Old_Downloader:
 
     async def start_file(self, album: str, media: MediaItem):
         """Handler for files and the progress bars for it"""
-        if media.complete:
+        if media.complete or await self.SQL_Helper.check_complete_singular(self.domain, media.url):
             await log(f"Previously Downloaded: {media.filename}", quiet=True)
             self.files.skipped_files += 1
             self.progress.update(1)
             return
-        else:
-            url_path = await get_db_path(URL(media.url), self.domain)
-            complete = await self.SQL_Helper.check_complete_singular(self.domain, url_path)
-            if complete:
-                await log(f"Previously Downloaded: {media.filename}", quiet=True)
-                self.files.skipped_files += 1
-                self.progress.update(1)
-                return
         async with self._semaphore:
-            url_path = await get_db_path(URL(media.url), self.domain)
+            url_path = await get_db_path(media.url, self.domain)
             await self.download_file(album, media, url_path)
 
     @retry
-    async def download_file(self, album: str, media: MediaItem, url_path: str):
+    async def download_file(self, album: str, media: MediaItem, url_path: str) -> None:
         """File downloader"""
         if not await check_free_space(self.required_free_space, self.download_dir):
             await log("We've run out of free space.", quiet=True)
@@ -266,6 +235,9 @@ class Old_Downloader:
             async with aiofiles.open(self.errored_file, mode='a') as file:
                 await file.write(f"{media.url},{media.referer},{e.message}\n")
 
+    async def failed_files_progress(self) -> None:
+        self.progress.update(1)
+
     async def check_file_exists(self, complete_file, partial_file, media, album, url_path, original_filename,
                                 current_throttle):
         """Complicated checker for if a file already exists, and was already downloaded"""
@@ -284,10 +256,8 @@ class Old_Downloader:
 
             downloaded_filename = await self.SQL_Helper.get_downloaded_filename(url_path, original_filename)
             if not downloaded_filename:
-                iterations = 1
-                while True:
+                for iterations in itertools.count(1):
                     filename = f"{complete_file.stem} ({iterations}){media.ext}"
-                    iterations += 1
                     temp_complete_file = (self.download_dir / album / filename)
                     if not temp_complete_file.exists() and not await self.SQL_Helper.check_filename(filename):
                         media.filename = filename
@@ -314,23 +284,16 @@ class Old_Downloader:
 async def old_download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelper, client: Client,
                                scraper: ScrapeMapper) -> None:
     """Handler for cascades and the progress bars for it"""
-    user_threads = args["Runtime"]["simultaneous_downloads_per_domain"]
-
     files = Files()
 
-    downloaders = []
     tasks = []
     total_files = await Cascade.get_total()
     with tqdm(total=total_files, unit_scale=True, unit='Files', leave=True, initial=0,
               desc="Files Downloaded") as progress:
         for domain, domain_obj in Cascade.domains.items():
-            threads = user_threads if user_threads != 0 else multiprocessing.cpu_count()
-            if 'bunkr' in domain or 'pixeldrain' in domain or 'anonfiles' in domain:
-                threads = 2 if (threads > 2) else threads
-            download_semaphore = asyncio.Semaphore(threads)
-            downloaders.append(Old_Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
-                                              download_semaphore, files, progress))
-        for downloader in downloaders:
+            threads = await get_threads_number(args, domain)
+            downloader = Old_Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
+                                        files, progress)
             tasks.append(downloader.start_domain())
         await asyncio.gather(*tasks)
 
@@ -342,24 +305,17 @@ async def old_download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQL
 async def old_download_forums(args: dict, Forums: ForumItem, SQL_Helper: SQLHelper, client: Client,
                               scraper: ScrapeMapper) -> None:
     """Handler for forum threads and the progress bars for it"""
-    user_threads = args["Runtime"]["simultaneous_downloads_per_domain"]
-
     files = Files()
     total_files = await Forums.get_total()
     with tqdm(total=total_files, unit_scale=True, unit='Files', leave=True, initial=0,
               desc="Files Downloaded") as progress:
         for title, Cascade in Forums.threads.items():
-            downloaders = []
             tasks = []
 
             for domain, domain_obj in Cascade.domains.items():
-                threads = user_threads if user_threads != 0 else multiprocessing.cpu_count()
-                if 'bunkr' in domain or 'pixeldrain' in domain or 'anonfiles' in domain:
-                    threads = 2 if (threads > 2) else threads
-                download_semaphore = asyncio.Semaphore(threads)
-                downloaders.append(Old_Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
-                                                  download_semaphore, files, progress))
-            for downloader in downloaders:
+                threads = await get_threads_number(args, domain)
+                downloader = Old_Downloader(args, client, SQL_Helper, scraper, threads, domain, domain_obj,
+                                            files, progress)
                 tasks.append(downloader.start_domain())
             await asyncio.gather(*tasks)
 
